#
# spec file for package rssguard
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rssguard
Version:        3.5.6
Release:        lp151.2.64
Summary:        RSS/ATOM/RDF feed reader
License:        GPL-3.0-only AND AGPL-3.0-or-later
Group:          Productivity/Networking/News/Utilities
Url:            https://github.com/martinrotter/rssguard
Source0:        https://github.com/martinrotter/rssguard/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.changes
# PATCH-FIX-UPSTREAM rssguard-3.5.2-fix_no_return_nonvoid.patch
Patch0:         rssguard-3.5.2-fix_no_return_nonvoid.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core) >= 5.8
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
Obsoletes:      %{name}-lang < %{version}
Provides:       %{name}-lang = %{version}

%description
RSS Guard is a RSS/ATOM feed aggregator developed using the Qt framework.
It supports online feed synchronization.

%prep
%setup -q
%patch0 -p1

# Remove build time references so build-compare can do its work
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{SOURCE1} '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{SOURCE1} '+%%b %%e %%Y')
sed -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" -i src/gui/dialogs/formabout.cpp
sed -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -i src/gui/dialogs/formabout.cpp

%build
lrelease-qt5 rssguard.pro
%qmake5 PREFIX=%{_prefix} USE_WEBENGINE=true
%make_jobs

%install
%qmake5_install
# install desktop icon & autostart
mkdir -pv %{buildroot}%{_datadir}/autostart
install -m0644 resources/desktop/com.github.%{name}.desktop.autostart -t %{buildroot}%{_datadir}/autostart
chmod -x %{buildroot}%{_datadir}/metainfo/com.github.%{name}.appdata.xml
%fdupes -s %{buildroot}

%files
%doc LICENSE.md
%dir %{_datadir}/applications
%dir %{_datadir}/autostart
%dir %{_datadir}/metainfo
%{_bindir}/%{name}
%{_datadir}/applications/com.github.%{name}.desktop
%{_datadir}/autostart/com.github.%{name}.desktop.autostart
%{_datadir}/metainfo/com.github.%{name}.appdata.xml
%{_datadir}/pixmaps/%{name}.png

%changelog
* Mon Feb 26 2018 aloisio@gmx.com
- Update to version 3.5.6
  Fixed:
  * Some minor stuff fixes.
  * Unnecessary "Welcome" notifications. (bug #176)
  * Bad handling of null/empty strings when inserting messages
    into DB. (bug #169)
  * Bad conversion of "created on" date/time in TT-RSS plugin.
    (bug #172)
  * Missing obligatory attribute in OPML 2.0 files. (bug #166)
* Sun Nov 19 2017 aloisio@gmx.com
- Update to version 3.5.5
  Added:
  * Internal message web viewer (and also lighter message text
    viewer) now support (#63) text searching. How to use:
    + Select some messages, it now gets displayed in internal
    viewer.
    + Give focus to internal viewer (click somehwere in it).
    + Press standard "find" keyboard shortcut (CTRL+F on Windows).
    + Search box appears on the bottom if internal message
    previewer.
  * New context menu internal web viewer action to open links in
    ext. browser (#80)
  * New bindable menu action Messages -> Enable message preview,
    which can disable opening message preview in internal web
    viewer. (#141)
  Fixed:
  * Displaying correct update files. (#155)
* Tue Nov  7 2017 aloisio@gmx.com
- Added AGPL-3.0+ license for QOAuth sources
* Mon Oct 23 2017 aloisio@gmx.com
- Update to version 3.5.4
  Fixed:
  * First item in itemviews is now selected when focus is gained.
    (#142)
  * Some feed files do not have URLs of messages properly
    sanitized. Strip "\n" and "\t" from URls. (bug #154)
* Fri Oct 20 2017 aloisio@gmx.com
- Update to version 3.5.2 (no changelog supplied)
- Added rssguard-3.5.2-fix_no_return_nonvoid.patch
* Mon Oct 16 2017 aloisio@gmx.com
- Update to version 3.5.1
  * Font size of message/feed list can now be changed. (#145)
  * Inoreader plugin can mark messages starred and accounts can be
    deleted.
  * All cached online service data are synchronously saved when
    any feed is updated.
* Tue Oct 10 2017 aloisio@gmx.com
- Update to version 3.5.0
  * All application resources (skins, icons, ...) are now compiled
    into the executable file. This allows for easier deployment.
  * "Add account" dialog is displayed when app is launched and no
    accounts exist so far.
  * New plugin for Inoreader. This is supported only in full RSS
    Guard "web-engine" version, because of web OAuth 2.0. The new
    plugins is in EXPERIMENTAL phase, expect errors and report them.
  * NextCloud plugin now allows to persistently set max number of
    messages to get downloaded per feed.
  * Added support for arbitrary external tools (settings category
    "Web browser & e-mail & proxy") which can open URLs of selected
    messages. (#136)
  * Standard account is now automatically added if RSS Guard is
    started with empty database.
  * Menu action "Select next unread message" in "Messages" menu
    now works across all feeds, so user can navigate through all
    unread messages with a sigle keyboard shortcut. (#132, #6)
  * Added two bindable menu actions (in menu "Web browser & tabs")
    which allow to cycle among tabs. (#6)
- Drop -lang subpackage since localisation is embedded in the
  executable now.
* Wed Sep  6 2017 aloisio@gmx.com
- Update to version 3.4.2
  * All (well, almost all) web-engine attributes can be
    disabled/enabled, including JS/plugins. (#57)
  * Some minor tweaks/fixes.
  * New Ad-Block feature for internal web browser. Based on Qt
    examples and QupZilla. Original license GNU GPLv3 is retained.
    (#123)
* Thu Jul 13 2017 aloisio@gmx.com
- Update to version 3.4.1
  Added:
  * Toolbar editor can reset toolbars.
  * Toolbar editor now uses iconified tool buttons.
  * Double mouse click on feed or recycle bin items in feeds list
    now opens all messages of the item in newspaper mode.
  * Columns in message list can be hidden/shown/reordered with
    context menu. (issue #115)
  * Auto-update notification is now switchable. (issue #119)
  * Messages which are not removed or restored are not instantly
    deleted from list, they are striked-through instead. This is
    more resource friendly.
  * Message list is now not reloaded when doing batch message
    operations.
  * Message list SQL queries are now fully adjustable. This will
    allow for integration of labels functionality in the future.
  * Auto-update status of feeds is now more general and complete.
    (issue #91)
  * Display feed title in list of messages. (issue #97)
  * Displayed feeds can now be sorted by multiple columns. Do you
    want to sort by author, and THEN by title? Simply click first
    "Title" column, then on "Author" column. If you hold CTRL during
    sorting, the sort is done in reverse column order.
  Changed:
  * Updating of RSS Guard now uses GitHub API. (issue #109)
  * Better ATOM/RSS parsing, respects now XML namespaces, bit
    better link parsing and other stuff. (issue #104)
  * Folder which holds SQL scripts got renamed to "sql".
  * Tweaked some conditions for determining newly "updated"
    messages in ATOM format. (issue #103)
  Fixed:
  * Fixed regression when restoring deleted messages.
  * Crash in TT-RSS plugin on application exit, when TT-RSS user
    needed to be logged out.
* Mon Mar 13 2017 aloisio@gmx.com
- Update to version 3.4.0
  Added:
  * New icons (CC 3.0 BY) inspired by the work of Dave Gandy.
  * "Cleanup database" action has now configurable shortcut.
    (issue #90)
  * Fixed #76, now user can choose to "not show the dialog
    again" when opening hyperlink from message previewer. This
    only concerns the lite version of RSS Guard which uses
    simpler text component for message previewing.
  Changed:
  * (Linux only) Primary user data/config storage is now undex
    $HOME/.config/RSS Guard. XDG_CONFIG_HOME variable is
    respected. If old user data is detected, then old user data
    path is used. Note that the location of cache is now changed
    too to $XDG_{CACHE,DATA}_HOME/RSS Guard.
  * RSS Guard now uses "_" character as localization file
    names separator. (issue #75)
  * Localizations are now placed in "translations" subfolder
    instead of "l10n" subfolder. (issue #75)
  version 3.3.8
  Fixed:
  * Percent HTML encoding is now decoded when messages are
    downloaded. (bug #83)
- Dropped rssguard-locale.patch (integrated upstream)
- Dropped rssguard-rpmlintrc
* Tue Jan 24 2017 jengelh@inai.de
- Update for description guidelines.
* Tue Jan 24 2017 aloisio@gmx.com
- Update to version 3.3.7
  Added:
  * Some localizations added & updated.
  * User now can place custom user skins in user "data"
    folder. (issue #81) See "About" dialog for the exact path.
  * User now can select if DB transactions are enabled or not.
    (bug #70) By default, DB transactions are now switched OFF,
    therefore anyone who wants better performance, must turn
    them ON in app settings.
  * MySQL database backend now requires at least version 5.5,
    DB encoding is now changed to utf8mb4 character set. (bug
    [#74])
  * Height if message attachment image is now configurable,
    defaults to 36. (issue #69)
  * All textual contents of all messages are now locally saved
    in explicit UTF-8 encoding. This is partially because of
    MySQL backend. We need to keep encoding of data sent to DB
    and encoding of DB itself in parity.
  Changed:
  * TT-RSS plugin now does NOT require service URL to be
    entered with "/api/" suffix. In other words, do not use that
    suffix now, RSS Guard will add it silently when it needs to.
  Fixed:
  * Fixed problem with strings in core being rendered
    untranslated. (bug #60)
  * Fixed problem with feed updates progress bar flickering.
    (bug #73)
  * Partially fixed problem with incorrect number of
    downloaded messages being reported. (bug #70)
- Refreshed rssguard-locale.patch
* Sat Dec  3 2016 aloisio@gmx.com
- Initial package (version 3.3.5)
